<template>
  <div class="container-fluid">
    <div class="row">
      <h3 class="text-center text-[22px]">Exam Centres</h3>
    </div>
    <button class="rounded-lg px-4 py-2 bg-blue-500 text-white font-semibold hover:bg-blue-600 duration-300" @click="openAddExamCentreModal = true, clearData()">
      Add Exam Centre
    </button>

    <div class="flex flex-col bg-white p-5 mt-4">
      <div class="overflow-x-auto sm:-mx-6 lg:-mx-8">
        <div class="inline-block min-w-full py-2 sm:px-6 lg:px-8">
          <div class="overflow-hidden">
            <table
              class="min-w-full border border-neutral-200 text-center text-sm font-light text-surface dark:border-white/10 dark:text-white"
            >
              <thead class="border-b border-neutral-200 font-medium dark:border-white/10">
                <tr>
                  <th
                    scope="col"
                    class="border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >#</th>
                  <th
                    scope="col"
                    class="border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >Name</th>
                  <th
                    scope="col"
                    class="border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >Code</th>
                  <th
                    scope="col"
                    class="border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >Action</th>
                </tr>
              </thead>
              <tbody>
                <tr v-for="(item, index) in centres" :key="index" class="border-b border-neutral-200 dark:border-white/10">
                  <td
                    class="whitespace-nowrap border-e border-neutral-200 px-6 py-4 font-medium dark:border-white/10"
                  >{{ ++index + indexValueForPagination }}</td>
                  <td
                    class="whitespace-nowrap border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >{{item.name}}</td>
                  <td
                    class="whitespace-nowrap border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >{{item.code}}</td>
                  <td
                    class="whitespace-nowrap border-e border-neutral-200 px-6 py-4 dark:border-white/10"
                  >
                  <button class="rounded-lg px-4 py-2 bg-green-700 text-green-100 hover:bg-green-800 duration-300" @click="handleEdit(item)">Edit</button>

                  <a-popconfirm
                    title="Are you sure delete this exam centre?"
                    ok-text="Yes"
                    cancel-text="No"
                    @confirm="handleDelete(item.id)"
                    class="rounded-lg px-4 py-2 bg-red text-red-100 hover:bg-red-700 duration-300 text-white"
                  >
                    <a href="#">Delete</a>
                  </a-popconfirm>
                  </td>
                </tr>
              </tbody>
            </table>
          </div>
        </div>
      </div>
    </div>

    
    <a-pagination
      v-if="pagination.last_page > 1"
      :total="pagination.total"
      :show-total="(total) => `Total ${pagination.total} items`"
      :size="String(pagination.total)"
      :default-current="1"
      :defaultPageSize="pagination.to"
      v-model="current"
      @change="onChange"
      class="text-center"
      style="padding-bottom: 10px; margin-top: 15px"
    />

  <div
    v-if="openAddExamCentreModal"
    class="text-left fixed inset-0 z-40 flex items-center justify-center overflow-x-hidden overflow-y-auto"
  >
    <!-- Backdrop -->
    <div class="fixed inset-0 bg-black bg-opacity-50"></div>

    <!-- Main modal container -->
    <div
      class="z-50 w-full max-w-2xl p-4 mx-auto my-20 overflow-hidden bg-white rounded-lg shadow-md dark:bg-gray-700"
    >
      <!-- Modal content -->
      <div class="relative">
        <!-- Modal header -->
        <div class="flex items-center justify-between p-5 rounded-t dark:border-gray-600">
          <h3 class="text-xl font-semibold text-gray-900 dark:text-white">
            <span v-if="addCentre.id">Edit</span>
            <span v-if="!addCentre.id">Add</span>
             Exam Centre
          </h3>
          <button
            type="button"
            class="text-gray-400 bg-transparent hover:bg-gray-200 hover:text-gray-900 rounded-lg text-sm p-1.5 ml-auto inline-flex items-center dark:hover:bg-gray-600 dark:hover:text-white"
            @click="openAddExamCentreModal = false"
          >
            <svg
              class="w-5 h-5"
              fill="none"
              stroke="currentColor"
              viewBox="0 0 24 24"
              xmlns="http://www.w3.org/2000/svg"
            >
              <path
                stroke-linecap="round"
                stroke-linejoin="round"
                stroke-width="2"
                d="M6 18L18 6M6 6l12 12"
              />
            </svg>
            <span class="sr-only">Close modal</span>
          </button>
        </div>
        <!-- Modal body -->
        <div class="p-4 md:p-5 space-y-4">
          <div class="flex flex-wrap -mx-2 lg:-mx-4">
            <div class="w-full md:w-1/2 px-2 lg:px-4">
              <div class="mb-4 lg:mb-5">
                <label for class="block text-gray-700 text-sm font-bold mb-2">Name</label>
                <input
                  v-model="addCentre.name"
                  type="text"
                  placeholder="Name"
                  class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline"
                />
              </div>
            </div>
            <div class="w-full md:w-1/2 px-2 lg:px-4">
              <div class="mb-4 lg:mb-5">
                <label for class="block text-gray-700 text-sm font-bold mb-2">Code</label>
                <input
                  v-model="addCentre.code"
                  type="text"
                  placeholder="Code"
                  class="shadow appearance-none border rounded w-full py-2 px-3 text-gray-700 leading-tight focus:outline-none focus:shadow-outline"
                />
              </div>
            </div>
          </div>
        </div>
        <!-- Modal footer -->
        <div class="flex items-center justify-end pl-5 pe-5 rounded-b dark:border-gray-600">
          <button
            type="button"
            class="px-5 py-2.5 text-sm font-medium text-white bg-blue-700 rounded-lg hover:bg-blue-800 focus:ring-4 focus:outline-none focus:ring-blue-300 dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800 disabled:opacity-70 disabled:cursor-default"
            :disabled="loading"
            @click="handleSave"
          >
            <a-spin v-if="loading">
              <a-icon slot="indicator" type="loading" style="font-size: 24px" spin />
            </a-spin>
            <span v-else>Confirm</span>
          </button>
        </div>
      </div>
    </div>
  </div>
  </div>
</template>

<script>
import { Modal } from "ant-design-vue";
export default {
  data() {
    return {
      addCentre: {
        name: '',
        code: '',
        id: '',
      },
      submitted: false,
      centres: [],
      search: "",
      perPage: 30,
      query: "",
      totalData: 0,
      indexValueForPagination: 0,
      loading: false,
      pagination: {},
      current: 1,
      pageSize: "",
      openAddExamCentreModal: false,
    };
  },
  watch: {
    search() {
      if (this.search.length == 0) {
        this.getDatas();
      }
    },
    query: function(newQuery, oldQuery) {
      if (newQuery === "") {
        this.getDatas();
      } else {
        this.search();
      }
    }
  },
  methods: {
    onChange(next) {
      this.current = next;
      this.indexValueForPagination = 0;
      if (next == 1) return this.getDatas(next);

      this.indexValueForPagination =
        (next + this.indexValueForPagination) * this.perPage - this.perPage;
      this.getDatas(next);
    },
    handleDelete(examId) {
      axios
        .post("/delete-exam-centre",{
          id: examId
        })
        .then(response => {
          this.$message.success("Successfully deleted.");
          this.getDatas();
        })
        .catch(error => {
          this.loading = false;
        });
    },

    handleCurrentChange(next) {
      this.indexValueForPagination = 0;
      if (next == 1) return this.getDatas(next);

      this.indexValueForPagination =
        (next + this.indexValueForPagination) * this.perPage - this.perPage;
      this.getDatas(next);
    },
    handleSearch() {
      if (this.search.length > 0 || this.search.length == 0) {
        this.getDatas();
      }
    },
    getDatas(nextPage = null) {
      this.loading = true;

      let url = `/exam-centre-list?per_page=${this.perPage}`;

      if (nextPage) {
        url += `&page=${nextPage}`;
      }
      if (this.search.length) {
        url += `&search=${this.search}`;
      }
      axios
        .get(url)
        .then(response => {
          this.centres = response.data.exam_centre.data;
          this.totalData = response.data.exam_centre.total;
          this.pagination = response.data.exam_centre;
          this.pageSize =
            parseInt(this.pagination.total) / parseInt(this.pagination.to);
          this.loading = false;
        })
        .catch(error => {
          this.loading = false;
        });
    },

    handleSave(){
      if(!this.addCentre.name){
        return this.$message.error("Name field is required.");
      }
      if(!this.addCentre.code){
        return this.$message.error("Code field is required.");
      }
      this.loading = true
      axios
        .post("/add-exam-centre", this.addCentre)
        .then(response => {
          if(!response.data.status){
            this.$message.error(response.data.message);
          }else{
            this.$message.success("Successfully added.");
            this.loading = false
            this.openAddExamCentreModal= false
            this.clearData()
          }
          this.getDatas()
        })
        .catch(error => {
          this.loading = false;
        });
    },
    handleEdit(item){
      this.addCentre = {...item}
      this.openAddExamCentreModal= true
    },
    clearData(){
      this.addCentre.name = ''
      this.addCentre.code = ''
      this.addCentre.id = ''
    }
  },

  mounted() {
    this.getDatas(this.pageSize);
  }
};
</script>
